@@ -21,9 +21,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SCREENLOCKER_INTERFACE_H
 #define SCREENLOCKER_INTERFACE_H
 
-#include <QtCore/QObject>
-#include <QtDBus/QDBusContext>
-#include <QtDBus/QDBusMessage>
+#include <QObject>
+#include <QDBusContext>
+#include <QDBusMessage>
 
 class QDBusServiceWatcher;
 
@@ -44,8 +44,8 @@ class Interface : public QObject, protected QDBusContext
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.ScreenSaver")
 public:
-    explicit Interface(KSldApp *parent = 0);
-    virtual ~Interface();
+    explicit Interface(KSldApp *parent = nullptr);
+    ~Interface() override;
 
 public Q_SLOTS:
     /**
